@@ -37,17 +37,11 @@ fn load_execute() -> Result<(), Box<dyn Error>> {
 }
 
 fn bdos_call(c: &CPU) {
-    #[cfg(debug_assertions)]
-    {
-        println!("BDOS CALL");
-    }
-
     if c.registers.c == 0x09 {
         let mut a = c.registers.get_de();
         loop {
             let c = c.bus.read_byte(a);
             if c as char == '$' {
-                println!("");
                 break;
             } else {
                 a += 1;
